@@ -3,7 +3,7 @@ package Safe;
 use 5.003_11;
 use strict;
 
-$Safe::VERSION = "2.14";
+$Safe::VERSION = "2.15";
 
 # *** Don't declare any lexicals above this point ***
 #
@@ -47,6 +47,21 @@ my $default_share = [qw[
     *_
     &PerlIO::get_layers
     &Regexp::DESTROY
+    &UNIVERSAL::isa
+    &UNIVERSAL::can
+    &UNIVERSAL::VERSION
+    &utf8::is_utf8
+    &utf8::valid
+    &utf8::encode
+    &utf8::decode
+    &utf8::upgrade
+    &utf8::downgrade
+    &utf8::native_to_unicode
+    &utf8::unicode_to_native
+    $version::VERSION
+    $version::CLASS
+    @version::ISA
+], ($] >= 5.010 && qw[
     &re::is_regexp
     &re::regname
     &re::regnames
@@ -60,18 +75,7 @@ my $default_share = [qw[
     &Tie::Hash::NamedCapture::NEXTKEY
     &Tie::Hash::NamedCapture::SCALAR
     &Tie::Hash::NamedCapture::flags
-    &UNIVERSAL::isa
-    &UNIVERSAL::can
     &UNIVERSAL::DOES
-    &UNIVERSAL::VERSION
-    &utf8::is_utf8
-    &utf8::valid
-    &utf8::encode
-    &utf8::decode
-    &utf8::upgrade
-    &utf8::downgrade
-    &utf8::native_to_unicode
-    &utf8::unicode_to_native
     &version::()
     &version::new
     &version::(""
@@ -88,7 +92,9 @@ my $default_share = [qw[
     &version::noop
     &version::is_alpha
     &version::qv
-]];
+]), ($] >= 5.011 && qw[
+    &re::regexp_pattern
+])];
 
 sub new {
     my($class, $root, $mask) = @_;
